Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(129)

Unified Diff: content/child/request_info.h

Issue 1411813003: Teach URLRequest about initiator checks for First-Party-Only cookies. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Feedback. Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/child/request_info.h
diff --git a/content/child/request_info.h b/content/child/request_info.h
index c583ee41eb2fdaad43fee23b54d9124e2c442660..776b63faaa511808b728b459893a4345d4ecc1b3 100644
--- a/content/child/request_info.h
+++ b/content/child/request_info.h
@@ -21,6 +21,7 @@
#include "third_party/WebKit/public/platform/WebTaskRunner.h"
#include "third_party/WebKit/public/platform/WebURLRequest.h"
#include "url/gurl.h"
+#include "url/origin.h"
namespace blink {
class WebTaskRunner;
@@ -39,10 +40,13 @@ struct CONTENT_EXPORT RequestInfo {
// Absolute URL encoded in ASCII per the rules of RFC-2396.
GURL url;
// URL of the document in the top-level window, which may be checked by the
// third-party cookie blocking policy.
GURL first_party_for_cookies;
+ // The origin of the context which initiated the request.
+ url::Origin request_initiator;
+
// Optional parameter, the referrer to use for the request for the url member.
Referrer referrer;
@@ -39,10 +40,13 @@ struct CONTENT_EXPORT RequestInfo {
// Absolute URL encoded in ASCII per the rules of RFC-2396.
GURL url;
- // URL of the document in the top-level window, which may be checked by the
- // third-party cookie blocking policy.
+ // URL representing the first-party origin for the request, which may be
+ // checked by the third-party cookie blocking policy.
GURL first_party_for_cookies;

Powered by Google App Engine
This is Rietveld 408576698